#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @useDynLib spFFBS, .registration = TRUE
## usethis namespace: end
NULL

## usethis namespace: start
#' @importFrom Rcpp sourceCpp
## usethis namespace: end
NULL
